@@ -558,7 +558,7 @@ ggv_prefs_dialog_new()
         table = gtk_table_new(10, 2, FALSE);
 
         /* zoom choice menu */
-        label = gtk_label_new_with_mnemonic(_("_Default Zoom:"));
+        label = gtk_label_new_with_mnemonic(_("Default _Zoom:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_RIGHT);
 
@@ -615,7 +615,7 @@ ggv_prefs_dialog_new()
         gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->auto_fit);
 
         /* units choice menu */
-        label = gtk_label_new_with_mnemonic(_("_Coordinate units:"));
+        label = gtk_label_new_with_mnemonic(_("Coordinate _units:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_RIGHT);
 
